@@ -2,11 +2,10 @@ package App::cpm::Logger::File;
 use strict;
 use warnings;
 
+use App::cpm::Util 'WIN32';
 use File::Temp ();
 use POSIX ();
 
-use constant WIN32 => $^O eq 'MSWin32';
-
 sub new {
     my ($class, $file) = @_;
     my $fh;
